==> owncloud-10.2.0.zip: owncloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Otrzymano błędne żądanie tokenów. Sprawdź, czy klucz aplikacji oraz klucz poufny są poprawne.",
    "Please provide a valid app key and secret." : "Proszę podać prawidłowy klucz aplikacji i klucz sekretny.",
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Dropbox App Configuration" : "Konfiguracja aplikacji Dropbox",
    "Google Drive App Configuration" : "Konfiguracja aplikacji Google Drive",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Error configuring OAuth1" : "Błąd konfiguracji OAuth1",
    "Error configuring OAuth2" : "Błąd konfiguracji OAuth2",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Saved" : "Zapisano",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Wyłączenie zewnętrznych zasobów danych odłączy wszystkie zewnętrzne zasoby aktualnych użytkowników. Czy na pewno chcesz kontynuować?",
    "Disable external storage" : "Wyłącz zewnętrzne zasoby",
    "Empty response from the server" : "Otrzymano pustą odpowiedź z serwera",
    "External mount error" : "Błąd zewnętrznego montowania",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Credentials required" : "Wymagane poświadczenia",
    "Save" : "Zapisz",
    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "Access key" : "Klucz dostępu",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "API key" : "Klucz API",
    "RSA public key" : "Klucz publiczny RSA",
    "Public key" : "Klucz publiczny",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kosz",
    "Hostname" : "Nazwa serwera",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Włącz SSL",
    "Enable Path Style" : "Włącz styl ścieżki",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Dropbox" : "Dropbox",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "ownCloud" : "ownCloud",
    "Host" : "Host",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "Share" : "Udostępnij",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "OpenStack Object Storage" : "Magazyn obiektów OpenStack",
    "<b>Note:</b> " : "<b>Uwaga:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla cURL w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> \"%s\" nie jest zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "External Storage" : "Zewnętrzna zasoby dyskowe",
    "Folder name" : "Nazwa folderu",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Add storage" : "Dodaj zasoby dyskowe",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Service name" : "Nazwa usługi",
    "External storage has been disabled by the administrator" : "Zewnętrzne zasoby dyskowe zostały wyłączone przez administratora",
    "Credentials saving failed" : "Nie udało się zapisać danych logowania",
    "Credentials saved" : "Dane logowania zapisane",
    "Allow users to mount external storage" : "Zezwól użytkownikom na montowanie pamięci zewnętrznych",
    "There was an error with message: " : "Wystąpił błąd o treści:",
    "Domain" : "Domena",
    "Enable sharing" : "Włącz współdzielenie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> owncloud-10.4.0.zip: owncloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Google Drive App Configuration" : "Konfiguracja aplikacji Google Drive",
    "Error verifying OAuth2 Code for " : "Błąd podczas weryfilacji kody OAuth2 dla",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Error configuring OAuth1" : "Błąd konfiguracji OAuth1",
    "Please provide a valid app key and secret." : "Proszę podać prawidłowy klucz aplikacji i klucz sekretny.",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Saved" : "Zapisano",
    "Disabling external storage will unmount all storages for all users, are you sure ?" : "Wyłączenie zewnętrznych zasobów danych odłączy wszystkie zewnętrzne zasoby aktualnych użytkowników. Czy na pewno chcesz kontynuować?",
    "Disable external storage" : "Wyłącz zewnętrzne zasoby",
    "Empty response from the server" : "Otrzymano pustą odpowiedź z serwera",
    "There was an error with message: " : "Wystąpił błąd o treści:",
    "External mount error" : "Błąd zewnętrznego montowania",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Credentials saved" : "Dane logowania zapisane",
    "Credentials saving failed" : "Nie udało się zapisać danych logowania",
    "Credentials required" : "Wymagane poświadczenia",
    "Save" : "Zapisz",
    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "API key" : "Klucz API",
    "RSA public key" : "Klucz publiczny RSA",
    "Public key" : "Klucz publiczny",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Google Drive" : "Dysk Google",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Host",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Udostępnij",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "<b>Note:</b> " : "<b>Uwaga:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla cURL w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> \"%s\" nie jest zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Enable sharing" : "Włącz współdzielenie",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "External Storage" : "Zewnętrzna zasoby dyskowe",
    "External storage has been disabled by the administrator" : "Zewnętrzne zasoby dyskowe zostały wyłączone przez administratora",
    "Folder name" : "Nazwa folderu",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Add storage" : "Dodaj zasoby dyskowe",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Allow users to mount external storage" : "Zezwól użytkownikom na montowanie pamięci zewnętrznych",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
